@@ -61,7 +61,7 @@ def expandvars (variable):
 
 
 
-PREFIX = "/usr/local"
+PREFIX = "/home/mclasen/gnome"
 #
 # This raw variables are set by autotools without translating vars:
 #   E.G. bindir='${exec_prefix}/bin
